@@ -1,4 +1,5 @@
 from . import bernoulli
+from . import categorical
 from . import autoregressive
 from . import exponential
 from . import linearregression
@@ -7,6 +8,7 @@ from . import normal
 from . import poisson
 
 __all__ = ['bernoulli',
+           'categorical',
            'autoregressive',
            'exponential',
            'linearregression',
